==> huaweicloudsdkdrs-3.1.133-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/create_data_level_table_compare_job_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateDataLevelTableCompareJobRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'job_id': 'str',
        'body': 'CreateDataLevelTableCompareJobReq'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'job_id': 'job_id',
        'body': 'body'
    }

    def __init__(self, x_language=None, job_id=None, body=None):
        """CreateDataLevelTableCompareJobRequest

        The model defined in huaweicloud sdk

        :param x_language: 请求语言类型。
        :type x_language: str
        :param job_id: 任务ID。
        :type job_id: str
        :param body: Body of the CreateDataLevelTableCompareJobRequest
        :type body: :class:`huaweicloudsdkdrs.v3.CreateDataLevelTableCompareJobReq`
        """
        
        

        self._x_language = None
        self._job_id = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.job_id = job_id
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        """Gets the x_language of this CreateDataLevelTableCompareJobRequest.

        请求语言类型。

        :return: The x_language of this CreateDataLevelTableCompareJobRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this CreateDataLevelTableCompareJobRequest.

        请求语言类型。

        :param x_language: The x_language of this CreateDataLevelTableCompareJobRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def job_id(self):
        """Gets the job_id of this CreateDataLevelTableCompareJobRequest.

        任务ID。

        :return: The job_id of this CreateDataLevelTableCompareJobRequest.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this CreateDataLevelTableCompareJobRequest.

        任务ID。

        :param job_id: The job_id of this CreateDataLevelTableCompareJobRequest.
        :type job_id: str
        """
        self._job_id = job_id

    @property
    def body(self):
        """Gets the body of this CreateDataLevelTableCompareJobRequest.

        :return: The body of this CreateDataLevelTableCompareJobRequest.
        :rtype: :class:`huaweicloudsdkdrs.v3.CreateDataLevelTableCompareJobReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateDataLevelTableCompareJobRequest.

        :param body: The body of this CreateDataLevelTableCompareJobRequest.
        :type body: :class:`huaweicloudsdkdrs.v3.CreateDataLevelTableCompareJobReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDataLevelTableCompareJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.152-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/create_data_level_table_compare_job_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateDataLevelTableCompareJobRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'job_id': 'str',
        'body': 'CreateDataLevelTableCompareJobReq'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'job_id': 'job_id',
        'body': 'body'
    }

    def __init__(self, x_language=None, job_id=None, body=None):
        r"""CreateDataLevelTableCompareJobRequest

        The model defined in huaweicloud sdk

        :param x_language: 请求语言类型。
        :type x_language: str
        :param job_id: 任务ID。
        :type job_id: str
        :param body: Body of the CreateDataLevelTableCompareJobRequest
        :type body: :class:`huaweicloudsdkdrs.v3.CreateDataLevelTableCompareJobReq`
        """
        
        

        self._x_language = None
        self._job_id = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.job_id = job_id
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        r"""Gets the x_language of this CreateDataLevelTableCompareJobRequest.

        请求语言类型。

        :return: The x_language of this CreateDataLevelTableCompareJobRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        r"""Sets the x_language of this CreateDataLevelTableCompareJobRequest.

        请求语言类型。

        :param x_language: The x_language of this CreateDataLevelTableCompareJobRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def job_id(self):
        r"""Gets the job_id of this CreateDataLevelTableCompareJobRequest.

        任务ID。

        :return: The job_id of this CreateDataLevelTableCompareJobRequest.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        r"""Sets the job_id of this CreateDataLevelTableCompareJobRequest.

        任务ID。

        :param job_id: The job_id of this CreateDataLevelTableCompareJobRequest.
        :type job_id: str
        """
        self._job_id = job_id

    @property
    def body(self):
        r"""Gets the body of this CreateDataLevelTableCompareJobRequest.

        :return: The body of this CreateDataLevelTableCompareJobRequest.
        :rtype: :class:`huaweicloudsdkdrs.v3.CreateDataLevelTableCompareJobReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this CreateDataLevelTableCompareJobRequest.

        :param body: The body of this CreateDataLevelTableCompareJobRequest.
        :type body: :class:`huaweicloudsdkdrs.v3.CreateDataLevelTableCompareJobReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDataLevelTableCompareJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
